# FeatureResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**feature_sub_category** | [**FeatureJoinedFeatureSubCategoryResponseDto**](FeatureJoinedFeatureSubCategoryResponseDto.md) |  | [optional] 
**organization_feature_exclusions** | [**FeatureJoinedOrganizationFeatureExclusionResponseDto**](FeatureJoinedOrganizationFeatureExclusionResponseDto.md) |  | [optional] 
**model_populations** | [**FeatureJoinedModelPopulationResponseDto**](FeatureJoinedModelPopulationResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**column_name** | **str** |  | 
**column_alias** | **str** |  | 
**display_name** | **str** |  | 
**feature_sub_category_id** | **str** |  | 
**aggregation_type** | **str** |  | 
**is_filter** | **bool** |  | 
**is_trainable** | **bool** |  | 
**is_explainable** | **bool** |  | 
**is_categorical** | **bool** |  | 
**category_values** | **object** |  | [optional] 
**type** | **str** |  | 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

